diff avcodec.h @ 1548:dd544554ed42 libavcodec

AVRational sample_aspect_ratio aspect ratio in JPEG JFIF is SAR not DAR ! removed nonsense SAR guessing code various related cleanups bugs?
author michael
date Mon, 20 Oct 2003 20:23:46 +0000
parents 0183874861fd
children 5d53c03186a1
line wrap: on
line diff
--- a/avcodec.h	Mon Oct 20 10:33:13 2003 +0000
+++ b/avcodec.h	Mon Oct 20 20:23:46 2003 +0000
@@ -12,10 +12,11 @@
 #endif
 
 #include "common.h"
+#include "rational.h"
 
 #define FFMPEG_VERSION_INT     0x000408
 #define FFMPEG_VERSION         "0.4.8"
-#define LIBAVCODEC_BUILD       4686
+#define LIBAVCODEC_BUILD       4687
 
 #define LIBAVCODEC_VERSION_INT FFMPEG_VERSION_INT
 #define LIBAVCODEC_VERSION     FFMPEG_VERSION
@@ -1034,11 +1035,11 @@
 #define FF_PRED_MEDIAN 2
     
     /**
      * aspect ratio (0 if unknown).
      * - encoding: set by user.
      * - decoding: set by lavc.
      */
-    float aspect_ratio;
+    AVRational sample_aspect_ratio;
 
     /**
      * the picture in the bitstream.
@@ -1034,11 +1035,11 @@
     
     /**
-     * aspect ratio (0 if unknown).
+     * sample aspect ratio (0 if unknown).
      * - encoding: set by user.
      * - decoding: set by lavc.